@@ -3,7 +3,12 @@ import os
 import psutil
 # Allow use of TA_ env vars instead of HT_
 from hypertrace import env_var_settings
-env_var_settings.ENV_VAR_PREFIXES.append('TA')
+
+from traceableai.hypertrace_env_override import add_deprecation_to_ht_env
+
+env_var_settings.ENV_VAR_PREFIXES.insert(0, 'TA')
+
+add_deprecation_to_ht_env()
 from traceableai.agent import Agent # pylint:disable=C0413
 
 from traceableai.config.config import Config  # pylint:disable=C0413,C0412
